@@ -218,8 +218,8 @@ HSS_LMS_PrivateKeyInternal::HSS_LMS_PrivateKeyInternal(HSS_LMS_Params hss_params
    BOTAN_ARG_CHECK(m_identifier.size() == LMS_IDENTIFIER_LEN, "Invalid identifier size");
 }
 
-secure_vector<uint8_t> HSS_LMS_PrivateKeyInternal::sign(std::span<const uint8_t> msg) {
-   secure_vector<uint8_t> sig(HSS_Signature::size(hss_params()));
+std::vector<uint8_t> HSS_LMS_PrivateKeyInternal::sign(std::span<const uint8_t> msg) {
+   std::vector<uint8_t> sig(HSS_Signature::size(hss_params()));
    BufferStuffer sig_stuffer(sig);
    sig_stuffer.append(store_be(hss_params().L() - 1));
 
@@ -287,6 +287,7 @@ LMS_PrivateKey HSS_LMS_PrivateKeyInternal::hss_derive_child_lms_private_key(
    seed_generator.set_i(SEED_CHILD_I);
    auto child_identifier = seed_generator.gen<LMS_Identifier>(*hash, parent_sk.seed());
    child_identifier.resize(LMS_IDENTIFIER_LEN);
+   CT::unpoison(child_identifier);  // identifiers are part of the signature
 
    return LMS_PrivateKey(child_lms_lmots_params.lms_params(),
                          child_lms_lmots_params.lmots_params(),
