@@ -40,8 +40,7 @@
    #include <emscripten/emscripten.h>
 #endif
 
-#if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL) || defined(BOTAN_TARGET_OS_IS_ANDROID) || \
-   defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO)
+#if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL) || defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO)
    #include <sys/auxv.h>
 #endif
 
@@ -60,11 +59,6 @@
    #endif
 #endif
 
-#if defined(BOTAN_TARGET_OS_IS_ANDROID)
-   #include <elf.h>
-extern "C" char** environ;
-#endif
-
 #if defined(BOTAN_TARGET_OS_IS_IOS) || defined(BOTAN_TARGET_OS_IS_MACOS)
    #include <mach/vm_statistics.h>
    #include <sys/sysctl.h>
@@ -127,28 +121,41 @@ uint32_t OS::get_process_id() {
 #endif
 }
 
+bool OS::has_auxval() {
+#if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL)
+   return true;
+#elif defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO)
+   return true;
+#elif defined(BOTAN_TARGET_OS_HAS_AUXINFO)
+   return true;
+#else
+   return false;
+#endif
+}
+
+unsigned long OS::auxval_hwcap() {
+#if defined(AT_HWCAP)
+   return AT_HWCAP;
+#else
+   // If the value is not defined in a header we can see,
+   // but auxval is supported, return the Linux/Android value
+   return (OS::has_auxval()) ? 16 : 0;
+#endif
+}
+
+unsigned long OS::auxval_hwcap2() {
+#if defined(AT_HWCAP2)
+   return AT_HWCAP2;
+#else
+   // If the value is not defined in a header we can see,
+   // but auxval is supported, return the Linux/Android value
+   return (OS::has_auxval()) ? 26 : 0;
+#endif
+}
+
 unsigned long OS::get_auxval(unsigned long id) {
 #if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL)
    return ::getauxval(id);
-#elif defined(BOTAN_TARGET_OS_IS_ANDROID) && defined(BOTAN_TARGET_ARCH_IS_ARM32)
-
-   if(id == 0)
-      return 0;
-
-   char** p = environ;
-
-   while(*p++ != nullptr)
-      ;
-
-   Elf32_auxv_t* e = reinterpret_cast<Elf32_auxv_t*>(p);
-
-   while(e != nullptr) {
-      if(e->a_type == id)
-         return e->a_un.a_val;
-      e++;
-   }
-
-   return 0;
 #elif defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO)
    unsigned long auxinfo = 0;
    ::elf_aux_info(static_cast<int>(id), &auxinfo, sizeof(auxinfo));
@@ -168,8 +175,12 @@ unsigned long OS::get_auxval(unsigned long id) {
 
 bool OS::running_in_privileged_state() {
 #if defined(AT_SECURE)
-   return OS::get_auxval(AT_SECURE) != 0;
-#elif defined(BOTAN_TARGET_OS_HAS_POSIX1)
+   if(OS::has_auxval()) {
+      return OS::get_auxval(AT_SECURE) != 0;
+   }
+#endif
+
+#if defined(BOTAN_TARGET_OS_HAS_POSIX1)
    return (::getuid() != ::geteuid()) || (::getgid() != ::getegid());
 #else
    return false;
