@@ -26,10 +26,10 @@ std::unique_ptr<Botan::Private_Key> load_sm2_private_key(const VarMap& vars) {
    const BigInt xG = vars.get_req_bn("xG");
    const BigInt yG = vars.get_req_bn("yG");
    const BigInt order = vars.get_req_bn("Order");
-   const BigInt cofactor = vars.get_req_bn("Cofactor");
    const BigInt x = vars.get_req_bn("x");
+   const Botan::OID oid = Botan::OID(vars.get_req_str("Oid"));
 
-   Botan::EC_Group domain(p, a, b, xG, yG, order, cofactor);
+   Botan::EC_Group domain(oid, p, a, b, xG, yG, order);
 
    Botan::Null_RNG null_rng;
    return std::make_unique<Botan::SM2_PrivateKey>(null_rng, domain, x);
@@ -39,7 +39,7 @@ class SM2_Signature_KAT_Tests final : public PK_Signature_Generation_Test {
    public:
       SM2_Signature_KAT_Tests() :
             PK_Signature_Generation_Test(
-               "SM2", "pubkey/sm2_sig.vec", "P,A,B,xG,yG,Order,Cofactor,Ident,Msg,x,Nonce,Signature", "Hash") {}
+               "SM2", "pubkey/sm2_sig.vec", "P,A,B,xG,yG,Order,Oid,Ident,Msg,x,Nonce,Signature", "Hash") {}
 
       bool clear_between_callbacks() const override { return false; }
 
@@ -62,7 +62,7 @@ class SM2_Encryption_KAT_Tests final : public PK_Encryption_Decryption_Test {
    public:
       SM2_Encryption_KAT_Tests() :
             PK_Encryption_Decryption_Test(
-               "SM2", "pubkey/sm2_enc.vec", "P,A,B,xG,yG,Order,Cofactor,Msg,x,Nonce,Ciphertext", "Hash") {}
+               "SM2", "pubkey/sm2_enc.vec", "P,A,B,xG,yG,Order,Oid,Msg,x,Nonce,Ciphertext", "Hash") {}
 
       std::string default_padding(const VarMap& vars) const override { return vars.get_opt_str("Hash", "SM3"); }
 
@@ -86,6 +86,14 @@ class SM2_Keygen_Tests final : public PK_Key_Generation_Test {
       std::vector<std::string> keygen_params() const override { return {"secp256r1", "sm2p256v1"}; }
 
       std::string algo_name() const override { return "SM2"; }
+
+      std::unique_ptr<Botan::Public_Key> public_key_from_raw(std::string_view keygen_params,
+                                                             std::string_view /* provider */,
+                                                             std::span<const uint8_t> raw_pk) const override {
+         const auto group = Botan::EC_Group(keygen_params);
+         const auto public_point = group.OS2ECP(raw_pk);
+         return std::make_unique<Botan::SM2_PublicKey>(group, public_point);
+      }
 };
 
 BOTAN_REGISTER_TEST("pubkey", "sm2_keygen", SM2_Keygen_Tests);
