@@ -51,8 +51,8 @@ class TLS_Session_Tests final : public Test {
          result.test_eq("Roundtrip from der", session.DER_encode(), session_from_der.DER_encode());
 
          const Botan::SymmetricKey key("ABCDEF");
-         const std::vector<uint8_t> ctext1 = session.encrypt(key, Test::rng());
-         const std::vector<uint8_t> ctext2 = session.encrypt(key, Test::rng());
+         const std::vector<uint8_t> ctext1 = session.encrypt(key, this->rng());
+         const std::vector<uint8_t> ctext2 = session.encrypt(key, this->rng());
 
          result.test_ne(
             "TLS session encryption is non-determinsitic", ctext1.data(), ctext1.size(), ctext2.data(), ctext2.size());
