@@ -183,7 +183,7 @@ class Credentials_Manager_Test final : public Botan::Credentials_Manager {
 std::shared_ptr<Credentials_Manager_Test> create_creds(Botan::RandomNumberGenerator& rng,
                                                        bool with_client_certs = false) {
    // rsa and ecdsa are required for the tls module
-   const Botan::EC_Group ecdsa_params("secp256r1");
+   const auto ecdsa_params = Botan::EC_Group::from_name("secp256r1");
    const size_t rsa_params = 1024;
 
    auto rsa_ca_key = std::make_unique<Botan::RSA_PrivateKey>(rng, rsa_params);
@@ -296,7 +296,10 @@ class TLS_Handshake_Test final {
    private:
       class Test_Extension : public Botan::TLS::Extension {
          public:
-            static Botan::TLS::Extension_Code static_type() { return static_cast<Botan::TLS::Extension_Code>(666); }
+            static Botan::TLS::Extension_Code static_type() {
+               // NOLINTNEXTLINE(clang-analyzer-optin.core.EnumCastOutOfRange)
+               return static_cast<Botan::TLS::Extension_Code>(666);
+            }
 
             Botan::TLS::Extension_Code type() const override { return static_type(); }
 
@@ -379,7 +382,9 @@ class TLS_Handshake_Test final {
             void tls_examine_extensions(const Botan::TLS::Extensions& extn,
                                         Botan::TLS::Connection_Side which_side,
                                         Botan::TLS::Handshake_Type /*unused*/) override {
-               Botan::TLS::Extension* test_extn = extn.get(static_cast<Botan::TLS::Extension_Code>(666));
+               // NOLINTNEXTLINE(clang-analyzer-optin.core.EnumCastOutOfRange)
+               const auto extn_id = static_cast<Botan::TLS::Extension_Code>(666);
+               Botan::TLS::Extension* test_extn = extn.get(extn_id);
 
                if(test_extn == nullptr) {
                   m_results.test_failure("Did not receive test extension from peer");
@@ -431,7 +436,7 @@ class TLS_Handshake_Test final {
                Botan::RandomNumberGenerator& rng) override {
                if(std::holds_alternative<Botan::TLS::Group_Params>(group) &&
                   std::get<Botan::TLS::Group_Params>(group).wire_code() == 0xFEE1) {
-                  const Botan::EC_Group ec_group("secp112r1");
+                  const auto ec_group = Botan::EC_Group::from_name("numsp256d1");
                   return std::make_unique<Botan::ECDH_PrivateKey>(rng, ec_group);
                }
 
@@ -446,7 +451,7 @@ class TLS_Handshake_Test final {
                const Botan::TLS::Policy& policy) override {
                if(std::holds_alternative<Botan::TLS::Group_Params>(group) &&
                   std::get<Botan::TLS::Group_Params>(group).wire_code() == 0xFEE1) {
-                  const Botan::EC_Group ec_group("secp112r1");
+                  const auto ec_group = Botan::EC_Group::from_name("numsp256d1");
                   Botan::ECDH_PublicKey peer_key(ec_group, ec_group.OS2ECP(public_value));
                   Botan::PK_Key_Agreement ka(private_key, rng, "Raw");
                   return ka.derive_key(0, peer_key.public_value()).bits_of();
@@ -874,14 +879,18 @@ class TLS_Unit_Tests final : public Test {
          std::shared_ptr<Botan::TLS::Session_Manager> server_ses;
 
    #if defined(BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER)
-         client_ses.reset(new Botan::TLS::Session_Manager_SQLite("client pass", rng, ":memory:", 5));
-         server_ses.reset(new Botan::TLS::Session_Manager_SQLite("server pass", rng, ":memory:", 10));
-
-   #else
-         client_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
-         server_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
+         client_ses = std::make_shared<Botan::TLS::Session_Manager_SQLite>("client pass", rng, ":memory:", 5);
+         server_ses = std::make_shared<Botan::TLS::Session_Manager_SQLite>("server pass", rng, ":memory:", 5);
    #endif
 
+         if(!client_ses) {
+            client_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
+         }
+
+         if(!server_ses) {
+            server_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
+         }
+
          auto creds = create_creds(*rng);
 
    #if defined(BOTAN_HAS_TLS_CBC)
@@ -1013,12 +1022,17 @@ class TLS_Unit_Tests final : public Test {
                               "AEAD",
                               {{"groups", "brainpool256r1"}});
 
-   #if defined(BOTAN_HAS_CURVE_25519)
-         test_modern_versions(
-            "AES-128/GCM x25519", results, client_ses, server_ses, creds, rng, "ECDH", "AES-128/GCM", "AEAD", {{
-               "groups",
-               "x25519"
-            }});
+   #if defined(BOTAN_HAS_X25519)
+         test_modern_versions("AES-128/GCM x25519",
+                              results,
+                              client_ses,
+                              server_ses,
+                              creds,
+                              rng,
+                              "ECDH",
+                              "AES-128/GCM",
+                              "AEAD",
+                              {{"groups", "x25519"}});
    #endif
 
          test_modern_versions("AES-128/GCM FFDHE-2048",
@@ -1047,8 +1061,8 @@ class TLS_Unit_Tests final : public Test {
                               true);
 
    #if defined(BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER)
-         client_ses.reset(new Botan::TLS::Session_Manager_In_Memory(rng));
-         server_ses.reset(new Botan::TLS::Session_Manager_In_Memory(rng));
+         client_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
+         server_ses = std::make_shared<Botan::TLS::Session_Manager_In_Memory>(rng);
    #endif
 
    #if defined(BOTAN_HAS_AEAD_OCB)
@@ -1077,23 +1091,24 @@ class TLS_Unit_Tests final : public Test {
          // Test with a custom curve
 
          /*
-         * First register a curve, in this case secp112r1
+         * First register a curve, in this case numsp256d1
          */
-         const Botan::BigInt p("0xDB7C2ABF62E35E668076BEAD208B");
-         const Botan::BigInt a("0xDB7C2ABF62E35E668076BEAD2088");
-         const Botan::BigInt b("0x659EF8BA043916EEDE8911702B22");
+         const Botan::BigInt p("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF43");
+         const Botan::BigInt a("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40");
+         const Botan::BigInt b("0x25581");
+         const Botan::BigInt order("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE43C8275EA265C6020AB20294751A825");
 
-         const Botan::BigInt g_x("0x09487239995A5EE76B55F9C2F098");
-         const Botan::BigInt g_y("0xA89CE5AF8724C0A23E0E0FF77500");
-         const Botan::BigInt order("0xDB7C2ABF62E35E7628DFAC6561C5");
+         const Botan::BigInt g_x("0x01");
+         const Botan::BigInt g_y("0x696F1853C1E466D7FC82C96CCEEEDD6BD02C2F9375894EC10BF46306C2B56C77");
 
-         const Botan::OID oid("1.3.132.0.6");
-         Botan::OID::register_oid(oid, "secp112r1");
+         const Botan::OID oid("1.3.6.1.4.1.25258.4.1");
+
+         Botan::OID::register_oid(oid, "numsp256d1");
 
          // Creating this object implicitly registers the curve for future use ...
-         Botan::EC_Group reg_secp112r1(p, a, b, g_x, g_y, order, 1, oid);
+         Botan::EC_Group reg_numsp256d1(oid, p, a, b, g_x, g_y, order);
 
-         test_modern_versions("AES-256/GCM secp112r1",
+         test_modern_versions("AES-256/GCM numsp256d1",
                               results,
                               client_ses,
                               server_ses,
