@@ -73,7 +73,7 @@ class TLS_Policy_Unit_Tests final : public Test {
       static Test::Result test_peer_key_acceptable_ecdh(Botan::RandomNumberGenerator& rng) {
          Test::Result result("TLS Policy ECDH key verification");
    #if defined(BOTAN_HAS_ECDH)
-         Botan::EC_Group group_192("secp192r1");
+         const auto group_192 = Botan::EC_Group::from_name("secp192r1");
          auto ecdh_192 = std::make_unique<Botan::ECDH_PrivateKey>(rng, group_192);
 
          Botan::TLS::Policy policy;
@@ -84,7 +84,7 @@ class TLS_Policy_Unit_Tests final : public Test {
             result.test_success("Correctly rejecting 192 bit EC keys");
          }
 
-         Botan::EC_Group group_256("secp256r1");
+         const auto group_256 = Botan::EC_Group::from_name("secp256r1");
          auto ecdh_256 = std::make_unique<Botan::ECDH_PrivateKey>(rng, group_256);
          policy.check_peer_key_acceptable(*ecdh_256);
          result.test_success("Correctly accepting 256 bit EC keys");
@@ -95,7 +95,7 @@ class TLS_Policy_Unit_Tests final : public Test {
       static Test::Result test_peer_key_acceptable_ecdsa(Botan::RandomNumberGenerator& rng) {
          Test::Result result("TLS Policy ECDSA key verification");
    #if defined(BOTAN_HAS_ECDSA)
-         Botan::EC_Group group_192("secp192r1");
+         const auto group_192 = Botan::EC_Group::from_name("secp192r1");
          auto ecdsa_192 = std::make_unique<Botan::ECDSA_PrivateKey>(rng, group_192);
 
          Botan::TLS::Policy policy;
@@ -106,7 +106,7 @@ class TLS_Policy_Unit_Tests final : public Test {
             result.test_success("Correctly rejecting 192 bit EC keys");
          }
 
-         Botan::EC_Group group_256("secp256r1");
+         const auto group_256 = Botan::EC_Group::from_name("secp256r1");
          auto ecdsa_256 = std::make_unique<Botan::ECDSA_PrivateKey>(rng, group_256);
          policy.check_peer_key_acceptable(*ecdsa_256);
          result.test_success("Correctly accepting 256 bit EC keys");
